@@ -22,9 +22,7 @@
 #include <rpcsvc/crypt.h>
 #endif
 #include <errno.h>
-#ifndef HAVE_CRYPT_R
 #include <pthread.h>
-#endif
 #include "libstr.h"
 #include "liblist.h"
 #include "client.h"
@@ -495,6 +493,10 @@ int http_authentication_result(t_session *session, bool access_on_pwdfile_missin
 	char *auth_str;
 	int result = ha_DENIED;
 
+	if (is_letsencrypt_authentication_request(session)) {
+		return ha_ALLOWED;
+	}
+
 	if (session->host->passwordfile == NULL) {
 		return access_on_pwdfile_missing ? ha_ALLOWED : ha_DENIED;
 	} else if ((auth_str = get_http_header("Authorization:", session->http_headers)) != NULL) {
